From fbe3213fec12263c8c6ffa9967fcb3ee983dc189 Mon Sep 17 00:00:00 2001
From: Robin Appelman <icewind@owncloud.com>
Date: Mon, 3 Jun 2013 13:17:03 +0200
Subject: [PATCH] User: consisten variable naming

---
 lib/user.php | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/lib/user.php b/lib/user.php
index a57ee5b13ca..503ac3f7493 100644
--- a/lib/user.php
+++ b/lib/user.php
@@ -489,10 +489,10 @@ class OC_User {
 	/**
 	 * disables a user
 	 *
 	 * @param string $userid the user to disable
 	 */
-	public static function disableUser($userid) {
-		$user = self::getManager()->get($userid);
+	public static function disableUser($uid) {
+		$user = self::getManager()->get($uid);
 		if ($user) {
 			$user->setEnabled(false);
 		}
@@ -501,10 +501,10 @@ class OC_User {
 	/**
 	 * enable a user
 	 *
-	 * @param string $userid
+	 * @param string $uid
 	 */
-	public static function enableUser($userid) {
-		$user = self::getManager()->get($userid);
+	public static function enableUser($uid) {
+		$user = self::getManager()->get($uid);
 		if ($user) {
 			$user->setEnabled(true);
 		}
@@ -513,11 +513,11 @@ class OC_User {
 	/**
 	 * checks if a user is enabled
 	 *
-	 * @param string $userid
+	 * @param string $uid
 	 * @return bool
 	 */
-	public static function isEnabled($userid) {
-		$user = self::getManager()->get($userid);
+	public static function isEnabled($uid) {
+		$user = self::getManager()->get($uid);
 		if ($user) {
 			return $user->isEnabled();
 		} else {
@@ -489,10 +489,10 @@ class OC_User {
 	 * disables a user
 	 *
-	 * @param string $userid the user to disable
+	 * @param string $uid the user to disable
 	 */
-- 
GitLab